# Torado
A script that routes all your machine traffic through TOR Network. It changes IP every 5 minutes (change it in your needs)

## There are 2 versions. 'Torado.py' is for everything and it changes IP every 5 seconds. You just have to setup proxy. The 2nd version 'torado_browseronly.py'is only for browsers without setting up something. Ofcourse you can set also the 2nd version to work for everything too

#### Now either you setup your machine with SOCK5 proxy 127.0.0.1:9050 or you setup proxy in a software (from settigns as usually)
#### Note that you may need to run scrip with admin privilages

### For more informations visit Torado's github page from [here](https://github.com/th3knv/Torado/)

